<?xml version="1.0" ?><!DOCTYPE TS><TS language="hu_HU" version="2.0">
<context>
    <name>DesktopSwitch</name>
    <message>
        <source>Desktop %1</source>
        <translation>%1. asztal</translation>
    </message>
</context>
</TS>